=======
Credits
=======

Development Lead
----------------

Center for Data Science and Public Policy <datascifellows@gmail.com>

Contributors
------------

- Adolfo De Unánue
- Andrea Navarrete
- Avishek Kumar
- Benedict Kuester
- Eddie Lin
- Eric Potash
- Erika Salomon
- Hannes Koenig
- Jesse London
- Joe Walsh
- Kit Rodolfa
- Klaus Ackermann
- Matt Bauman
- Rayid Ghani
- Tristan Crockett
